@@ -1,4 +1,4 @@
-/*  $Revision: 1.2 $
+/*  $Id: sys2nf.c 8230 2008-12-14 16:49:28Z iulius $
 **
 **  Read a C news "sys" file and split it up into a set of INN
 **  newsfeeds entries.  Also works with B news.
@@ -6,16 +6,16 @@
 **  Once done, edit all files that have HELP or all in them.
 **  Review all files, anyway.
 */
-#include <stdio.h>
-#include <sys/types.h>
-#include "configdata.h"
+
+#include "config.h"
 #include "clibrary.h"
 #include <ctype.h>
 #include <errno.h>
 #include <sys/stat.h>
-#include "nntp.h"
+
+#include "inn/innconf.h"
 #include "libinn.h"
-#include "macros.h"
+#include "nntp.h"
 
 #define TEMPFILE	":tmp"
 static char		**Groups;
@@ -40,17 +40,17 @@ ReadActive(act)
     }
     for (i = 0; fgets(buff, sizeof buff, F) != NULL; i++)
 	continue;
-    Groups = NEW(char*, i + 2);
+    Groups = xmalloc((i + 2) * sizeof(char *));
 
     /* Fill in each word. */
     rewind(F);
     for (i = 0; fgets(buff, sizeof buff, F) != NULL; i++) {
 	if ((p = strchr(buff, ' ')) != NULL)
 	    *p = '\0';
-	Groups[i] = COPY(buff);
+	Groups[i] = xstrdup(buff);
     }
     Groups[i] = NULL;
-    (void)fclose(F);
+    fclose(F);
 }
 
 
@@ -62,10 +62,10 @@ char **
 ReadSys(sys)
     char		*sys;
 {
-    register char	*p;
-    register char	*to;
-    register char	*site;
-    register int	i;
+    char	*p;
+    char	*to;
+    char	*site;
+    int	i;
     char		*data;
     char		**strings;
 
@@ -78,7 +78,7 @@ ReadSys(sys)
 	continue;
 
     /* Scan the file, glue all multi-line entries. */
-    for (strings = NEW(char*, i + 1), i = 0, to = p = data; *p; ) {
+    for (strings = xmalloc((i + 1) * sizeof(char *)), i = 0, to = p = data; *p; ) {
 	for (site = to; *p; ) {
 	    if (*p == '\n') {
 		p++;
@@ -94,10 +94,10 @@ ReadSys(sys)
 	*to++ = '\0';
 	if (*site == '\0')
 	    continue;
-	strings[i++] = COPY(site);
+	strings[i++] = xstrdup(site);
     }
     strings[i] = NULL;
-    DISPOSE(data);
+    free(data);
     return strings;
 }
 
@@ -106,7 +106,7 @@ ReadSys(sys)
 **  Is this the name of a top-level group?  We want a simple name, "foo",
 **  and should find a "foo." in the group list.
 */
-static BOOL
+static bool
 Toplevel(p)
     char	*p;
 {
@@ -115,11 +115,11 @@ Toplevel(p)
     int		i;
 
     if (strchr(p, '.') != NULL)
-	return FALSE;
+	return false;
     for (i = strlen(p) - 1, gp = Groups; (g = *gp++) != NULL; )
-	if (EQn(p, g, i) && g[i + 1] == '.')
-	    return TRUE;
-    return FALSE;
+	if (strncmp(p, g, i) == 0 && g[i + 1] == '.')
+	    return true;
+    return false;
 }
 
 
@@ -127,7 +127,7 @@ Toplevel(p)
 **  Do we have a name that's a prefix for more then one newsgroup?
 **  For "foo.bar", we must find more then one "foo.bar" or "foo.bar."
 */
-static BOOL
+static bool
 GroupPrefix(p)
     char	*p;
 {
@@ -137,9 +137,9 @@ GroupPrefix(p)
     int		i;
 
     if (strchr(p, '.') == NULL)
-	return FALSE;
+	return false;
     for (i = strlen(p), count = 0, gp = Groups; (g = *gp++) != NULL; )
-	if (EQ(p, g) || (EQn(p, g, i) && g[i] == '.'))
+	if (strcmp(p, g) == 0 || (strncmp(p, g, i) == 0 && g[i] == '.'))
 	    count++;
     return count > 1;
 }
@@ -151,77 +151,87 @@ GroupPrefix(p)
 */
 static void
 DoSub(F, p)
-    register FILE	*F;
+    FILE	*F;
     char		*p;
 {
-    register char	*s;
-    register int	len;
-    register BOOL	SawBang;
-    register BOOL	SawAll;
+    char	*s;
+    int	len, i;
+    bool matched;
+    bool	SawBang;
+    bool	SawAll;
+
+    /* Distributions, not newsgroups. */
+    static const char * const distributions[] = {
+        "world", "na", "usa", "inet", "mod", "net", "local"
+    };
+
+    /* Newsgroup hierarchies. */
+    static const char * const hierarchies[] = {
+        "comp", "misc", "news", "rec", "sci", "soc", "talk", "alt", "bionet",
+        "bit", "biz", "clari", "ddn", "gnu", "ieee", "k12", "pubnet", "trial",
+        "u3b", "vmsnet",
+
+        "ba", "ca", "dc", "ne", "ny", "tx",
+
+        "info", "mail", "opinions", "uunet"
+    };
 
     if ((s = strtok(p, ",")) == NULL)
 	return;
 
-    (void)fprintf(F, "!*");
+    fprintf(F, "!*");
     len = 8 + 1 + 2;
     do {
-	/* These are distributions, not newsgroups. */
-	if (EQ(s, "world") || EQ(s, "na") || EQ(s, "usa") || EQ(s, "inet")
-	 || EQ(s, "mod") || EQ(s, "net")
-	 || EQ(s, "local")
-	)
-	    continue;
+        for (matched = false, i = 0; i < ARRAY_SIZE(distributions); i++)
+            if (strcmp(s, distributions[i]) == 0) {
+                matched = true;
+                break;
+            }
+        if (matched)
+            continue;
 
 	if (innconf->mergetogroups)
-	    if (EQ(s, "!to") || EQn(s, "to.", 3))
+	    if (strcmp(s, "!to") == 0 || strncmp(s, "to.", 3) == 0)
 		continue;
 
-	(void)putc(',', F);
+	putc(',', F);
 	len++;
 
 	if (len + strlen(s) + 3 > 72) {
-	    (void)fprintf(F,"\\\n\t    ");
+	    fprintf(F,"\\\n\t    ");
 	    len = 12;
 	}
 
 	SawBang = *s == '!';
 	if (SawBang) {
-	    (void)putc('!', F);
+	    putc('!', F);
 	    len++;
 	    s++;
 	}
 
-	SawAll = EQ(s, "all");
+	SawAll = (strcmp(s, "all") == 0);
 	if (SawAll)
-	    s = SawBang ? "*" : "*,!control";
+	    s = SawBang ? "*" : "*,!control,!control.*";
 	len += strlen(s);
-	(void)fprintf(F, "%s", s);
+	fprintf(F, "%s", s);
 
 	if (SawAll)
 	    ;
-	else if (
-	    EQ(s, "comp") || EQ(s, "misc") || EQ(s, "news") || EQ(s, "rec")
-	 || EQ(s, "sci") || EQ(s, "soc") || EQ(s, "talk")
+	else {
+            for (matched = false, i = 0; i < ARRAY_SIZE(distributions); i++)
+                if (strcmp(s, hierarchies[i]) == 0) {
+                    matched = true;
+                    break;
+                }
 
-	 || EQ(s, "alt") || EQ(s, "bionet") || EQ(s, "bit") || EQ(s, "biz")
-	 || EQ(s, "clari") || EQ(s, "ddn") || EQ(s, "gnu") || EQ(s, "ieee")
-	 || EQ(s, "k12") || EQ(s, "pubnet") || EQ(s, "trial") || EQ(s, "u3b")
-	 || EQ(s, "vmsnet")
-
-	 || EQ(s, "ba") || EQ(s, "ca") || EQ(s, "dc") || EQ(s, "ne")
-	 || EQ(s, "ny") || EQ(s, "tx")
-
-	 || EQ(s, "info") || EQ(s, "mail") || EQ(s, "opinions")
-	 || EQ(s, "uunet")
-
-	 || Toplevel(s)) {
-	    (void)fprintf(F, ".*");
-	    len += 2;
-	}
-	else if (GroupPrefix(s)) {
-	    (void)putc('*', F);
-	    len++;
-	}
+            if (matched) {
+                fprintf(F, ".*");
+                len += 2;
+            } else if (GroupPrefix(s)) {
+                putc('*', F);
+                len++;
+            }
+        }
     } while ((s = strtok((char *)NULL, ",")) != NULL);
 }
 
@@ -246,7 +256,8 @@ main(ac, av)
     char	*sys;
     int		i;
 
-    if (ReadInnConf() < 0) exit(1);
+    if (!innconf_read(NULL))
+        exit(1);
     /* Set defaults. */
     act = "/usr/local/lib/newslib/active";
     sys = "sys";
@@ -272,12 +283,12 @@ main(ac, av)
 	if ((p = *sites++) == NULL)
 	    break;
 	for (F = fopen(TEMPFILE, "w"); p && *p == '#'; p = *sites++)
-	    (void)fprintf(F, "%s\n", p);
+	    fprintf(F, "%s\n", p);
 	if (p == NULL) {
-	    (void)fclose(F);
+	    fclose(F);
 	    break;
 	}
-	site = COPY(p);
+	site = xstrdup(p);
 	if ((f2 = strchr(site, ':')) == NULL)
 	    f2 = "HELP";
 	else
@@ -292,19 +303,19 @@ main(ac, av)
 	    *f4++ = '\0';
 
 	/* Write the fields. */
-	(void)fprintf(F, "%s\\\n", site);
-	(void)fprintf(F, "\t:");
+	fprintf(F, "%s\\\n", site);
+	fprintf(F, "\t:");
 	DoSub(F, f2);
-	(void)fprintf(F, "\\\n");
-	if (EQ(f3, "n"))
-	    (void)fprintf(F, "\t:Tf,Wnm\\\n", f3);
+	fprintf(F, "\\\n");
+	if (strcmp(f3, "n") == 0)
+	    fprintf(F, "\t:Tf,Wnm\\\n", f3);
 	else
-	    (void)fprintf(F, "\t:HELP%s\\\n", f3);
-	(void)fprintf(F, "\t:%s\n", f4);
+	    fprintf(F, "\t:HELP%s\\\n", f3);
+	fprintf(F, "\t:%s\n", f4);
 	if (ferror(F) || fclose(F) == EOF)
 	    perror(TEMPFILE), exit(1);
 
-	DISPOSE(site);
+	free(site);
 
 	/* Find the sitename. */
 	for (q = p; *q && *q != '/' && *q != ':'; q++)
@@ -319,7 +330,7 @@ main(ac, av)
 	while ((i = fread(buff, 1, sizeof buff, F)) > 0)
 	    if (fwrite(buff, 1, i, out) != i)
 		perror(p), exit(1);
-	(void)fclose(F);
+	fclose(F);
 	if (fclose(out) == EOF)
 	    perror(p), exit(1);
 
