@@ -1,4 +1,4 @@
-/*  $Id: perl.c,v 1.15.2.1 2000/10/01 22:54:37 kondou Exp $
+/*  $Id: perl.c 7951 2008-08-05 19:41:17Z iulius $
 **
 **  Perl filtering support for innd.
 **
@@ -40,44 +40,35 @@
 #include "config.h"
 
 /* Skip this entire file if DO_PERL (./configure --with-perl) isn't set. */
-#if defined(DO_PERL)
+#if DO_PERL
 
 #include "clibrary.h"
 #include "innd.h"
-#include "art.h"
-
-/* Linux doesn't have bool, yet sets _G_HAVE_BOOL to true.  Hello? */
-#ifdef DO_NEED_BOOL
-typedef int bool;
-#endif
 
 #include <EXTERN.h>
 #include <perl.h>
 #include <XSUB.h>
 #include "ppport.h"
 
-/* From lib/perl.c. */
-extern BOOL		PerlFilterActive;
+#include "innperl.h"
 
 /* From art.c.  Ew.  Need header parsing that doesn't use globals. */
-extern ARTHEADER	ARTheaders[], *ARTheadersENDOF;
-extern char		*filterPath;
+extern char             *filterPath;
 
 /*
 **  Run an incoming article through the Perl article filter.  Returns NULL
 **  accept the article or a rejection message to reject it.
 */
 char *
-PLartfilter(char *artBody, int lines)
+PLartfilter(const ARTDATA *data, char *artBody, long artLen, int lines)
 {
     dSP;
-    ARTHEADER * hp;
+    const ARTHEADER * hp;
+    const HDRCONTENT *hc = data->HdrContent;
     HV *        hdr;
     CV *        filter;
-    int         rc;
+    int         i, rc;
     char *      p;
-    char        save = '\0';
-    static SV * body = NULL;
     static char buf[256];
 
     if (!PerlFilterActive) return NULL;
@@ -87,39 +78,27 @@ PLartfilter(char *artBody, int lines)
     /* Create %hdr and stash a copy of every known header.  Path has to be
        handled separately since it's been munged by article processing. */
     hdr = perl_get_hv("hdr", 1);
-    for (hp = ARTheaders; hp < ARTheadersENDOF; hp++) {
-        if (hp->Found && hp->Value && strcmp(hp->Name, "Path") != 0)
-            hv_store(hdr, (char *) hp->Name, strlen(hp->Name),
-                     newSVpv(hp->Value, 0), 0);
-    }
-    if (filterPath) {
-        p = strpbrk(filterPath, "\r\n");
-        if (p) {
-	    save = *p;
-	    *p = '\0';
+    for (i = 0 ; i < MAX_ARTHEADER ; i++) {
+	if (HDR_FOUND(i)) {
+	    hp = &ARTheaders[i];
+            hv_store(hdr, (char *) hp->Name, hp->Size, newSVpv(HDR(i), 0), 0);
 	}
-        hv_store(hdr, "Path", 4, newSVpv(filterPath, 0), 0);
-        if (p) *p = save;
     }
 
     /* Store the article body.  We don't want to make another copy of it,
-       since it could potentially be quite large.  Instead, stash the
-       pointer in the static SV * body.  We set LEN to 0 and inc the
-       refcount to tell Perl not to free it (either one should be enough).
-       Requires 5.004.  In testing, this produced a 17% speed improvement
-       over making a copy of the article body for a fairly heavy filter. */
+     * since it could potentially be quite large.  In testing, this produced
+     * a 17% speed improvement over making a copy of the article body
+     * for a fairly heavy filter.
+     * Available since Perl 5.7.1, newSVpvn_share allows to avoid such
+     * a copy (getting round its use for older versions of Perl leads
+     * to unreliable SV * bodies as for regexps).  And for Perl not to
+     * compute a hash for artBody, we give it "42". */
     if (artBody) {
-        if (!body) {
-            body = newSV(0);
-            (void) SvUPGRADE(body, SVt_PV);
-        }
-        SvPVX(body) = artBody;
-        SvCUR_set(body, strlen(artBody));
-        SvLEN_set(body, 0);
-        SvPOK_on(body);
-        (void) SvREADONLY_on(body);
-        (void) SvREFCNT_inc(body);
-        hv_store(hdr, "__BODY__", 8, body, 0);
+#if (PERL_REVISION == 5) && ((PERL_VERSION < 7) || ((PERL_VERSION == 7) && (PERL_SUBVERSION < 1)))
+        hv_store(hdr, "__BODY__", 8, newSVpv(artBody, artLen), 0);
+#else
+        hv_store(hdr, "__BODY__", 8, newSVpvn_share(artBody, artLen, 42), 0);
+#endif /* Perl < 5.7.1 */
     }
 
     hv_store(hdr, "__LINES__", 9, newSViv(lines), 0);
@@ -135,16 +114,15 @@ PLartfilter(char *artBody, int lines)
     /* Check $@, which will be set if the sub died. */
     buf[0] = '\0';
     if (SvTRUE(ERRSV)) {
-        syslog(L_ERROR, "Perl function filter_art died: %s",
+        syslog(L_ERROR, "Perl function filter_art died on article %s: %s",
+               HDR_FOUND(HDR__MESSAGE_ID) ? HDR(HDR__MESSAGE_ID) : "?",
                SvPV(ERRSV, PL_na));
         (void) POPs;
-        PerlFilter(FALSE);
+        PerlFilter(false);
     } else if (rc == 1) {
         p = POPp;
-        if (p && *p) {
-            strncpy(buf, p, sizeof(buf) - 1);
-            buf[sizeof(buf) - 1] = '\0';
-        }
+        if (p && *p)
+            strlcpy(buf, p, sizeof(buf));
     }
 
     PUTBACK;
@@ -183,16 +161,14 @@ PLmidfilter(char *messageID)
     /* Check $@, which will be set if the sub died. */
     buf[0] = '\0';
     if (SvTRUE(ERRSV)) {
-        syslog(L_ERROR, "Perl function filter_messageid died: %s",
-               SvPV(ERRSV, PL_na));
+        syslog(L_ERROR, "Perl function filter_messageid died on id %s: %s",
+               messageID, SvPV(ERRSV, PL_na));
         (void) POPs;
-        PerlFilter(FALSE);
+        PerlFilter(false);
     } else if (rc == 1) {
         p = POPp;
-        if (p && *p) {
-            strncpy(buf, p, sizeof(buf) - 1);
-            buf[sizeof(buf) - 1] = '\0';
-        }
+        if (p && *p)
+            strlcpy(buf, p, sizeof(buf));
     }
     
     PUTBACK;
@@ -244,7 +220,41 @@ PLmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
         syslog(L_ERROR, "Perl function filter_mode died: %s",
                 SvPV(ERRSV, PL_na));
         (void) POPs;
-        PerlFilter(FALSE);
+        PerlFilter(false);
+    }
+}
+
+
+/*
+**  Called by CCmode, this returns the Perl filter statistics if a Perl
+**  function to generate such statistics has been defined, or NULL otherwise.
+**  If a string is returned, it's in newly allocated memory that must be freed
+**  by the caller.
+*/
+char *
+PLstats(void)
+{
+    dSP;
+    char *argv[] = { NULL };
+    
+    if (perl_get_cv("filter_stats", false) == NULL)
+        return NULL;
+    else {
+        char *stats = NULL;
+        char *result;
+
+	ENTER;
+	SAVETMPS;
+	perl_call_argv("filter_stats", G_EVAL | G_NOARGS, argv);
+	SPAGAIN;
+        result = POPp;
+        if (result != NULL && *result)
+            stats = xstrdup(result);
+	PUTBACK;
+	FREETMPS;
+	LEAVE;
+
+        return stats;
     }
 }
 
@@ -279,7 +289,7 @@ XS(XS_INN_addhist)
 
     /* If any of the times are missing, they should default to now. */
     if (i < 4) {
-        sprintf(tbuff, "%ld", (long) time((time_t *) 0));
+        snprintf(tbuff, sizeof(tbuff), "%ld", (long) time(NULL));
         for (; i < 4; i++)
             parambuf[i] = tbuff;
     }
@@ -308,21 +318,20 @@ XS(XS_INN_article)
 {
     dXSARGS;
     char *      msgid;
-    TOKEN *     token;
+    TOKEN       token;
     ARTHANDLE * art;
     char *      p;
-    int         len;
+    size_t      len;
 
     if (items != 1)
 	croak("Usage: INN::article(msgid)");
 
     /* Get the article token from the message ID and the history file. */
     msgid = (char *) SvPV(ST(0), PL_na);
-    token = HISfilesfor(HashMessageID(msgid));
-    if (token == NULL) XSRETURN_UNDEF;
+    if (!HISlookup(History, msgid, NULL, NULL, NULL, &token)) XSRETURN_UNDEF;
 
     /* Retrieve the article and convert it from wire format. */
-    art = SMretrieve(*token, RETR_ALL);
+    art = SMretrieve(token, RETR_ALL);
     if (art == NULL) XSRETURN_UNDEF;
     p = FromWireFmt(art->data, art->len, &len);
     SMfreearticle(art);
@@ -330,7 +339,7 @@ XS(XS_INN_article)
     /* Push a copy of the article onto the Perl stack, free our temporary
        memory allocation, and return the article to Perl. */
     ST(0) = sv_2mortal(newSVpv(p, len));
-    DISPOSE(p);
+    free(p);
     XSRETURN(1);
 }
 
@@ -369,15 +378,14 @@ XS(XS_INN_filesfor)
 {
     dXSARGS;
     char        *msgid;
-    TOKEN       *token;
+    TOKEN       token;
 
     if (items != 1)
         croak("Usage: INN::filesfor(msgid)");
 
     msgid = (char *) SvPV(ST(0), PL_na);
-    token = HISfilesfor(HashMessageID(msgid));
-    if (token) {
-        XSRETURN_PV(TokenToText(*token));
+    if (HISlookup(History, msgid, NULL, NULL, NULL, &token)) {
+        XSRETURN_PV(TokenToText(token));
     } else {
         XSRETURN_UNDEF;
     }
@@ -396,7 +404,7 @@ XS(XS_INN_havehist)
         croak("Usage: INN::havehist(msgid)");
 
     msgid = (char *) SvPV(ST(0), PL_na);
-    if (HIShavearticle(HashMessageID(msgid)))
+    if (HIScheck(History, msgid))
         XSRETURN_YES;
     else
         XSRETURN_NO;
@@ -412,21 +420,20 @@ XS(XS_INN_head)
 {
     dXSARGS;
     char *      msgid;
-    TOKEN *     token;
+    TOKEN       token;
     ARTHANDLE * art;
     char *      p;
-    int         len;
+    size_t      len;
 
     if (items != 1)
         croak("Usage: INN::head(msgid)");
 
     /* Get the article token from the message ID and the history file. */
     msgid = (char *) SvPV(ST(0), PL_na);
-    token = HISfilesfor(HashMessageID(msgid));
-    if (token == NULL) XSRETURN_UNDEF;
+    if (!HISlookup(History, msgid, NULL, NULL, NULL, &token)) XSRETURN_UNDEF;
 
     /* Retrieve the article header and convert it from wire format. */
-    art = SMretrieve(*token, RETR_HEAD);
+    art = SMretrieve(token, RETR_HEAD);
     if (art == NULL) XSRETURN_UNDEF;
     p = FromWireFmt(art->data, art->len, &len);
     SMfreearticle(art);
@@ -434,7 +441,7 @@ XS(XS_INN_head)
     /* Push a copy of the article header onto the Perl stack, free our
        temporary memory allocation, and return the header to Perl. */
     ST(0) = sv_2mortal(newSVpv(p, len));
-    DISPOSE(p);
+    free(p);
     XSRETURN(1);
 }
 
@@ -476,7 +483,7 @@ XS(XS_INN_newsgroup)
 **  Initialize the XS callbacks defined in this file.
 */
 void
-PLxsinit()
+PLxsinit(void)
 {
     newXS("INN::addhist", XS_INN_addhist, "perl.c");
     newXS("INN::article", XS_INN_article, "perl.c");
