@@ -1,4 +1,4 @@
-/*  $Id: commands.c 7542 2006-08-26 05:57:11Z eagle $
+/*  $Id: commands.c 8012 2008-09-07 10:31:33Z iulius $
 **
 **  Miscellaneous commands.
 */
@@ -81,6 +81,8 @@ PERMgeneric(char *av[], char *accesslist)
 
     /* Create a pipe. */
     if (pipe(pan) < 0) {
+        Reply("%d Can't pipe %s\r\n", NNTP_TEMPERR_VAL,
+              strerror(errno));
 	syslog(L_FATAL, "cant pipe for %s %m", av[0]);
 	return -1;
     }
@@ -476,20 +478,20 @@ CMDpost(int ac UNUSED, char *av[] UNUSED)
        * invoke the spaghetti factor). 
        */
       if ((path = (char *) PostRecFilename(ClientIpString,PERMuser)) == NULL) {
-        Reply("%s\r\n", NNTP_CANTPOST);
+        Reply("%s\r\n", ihave ? NNTP_RESENDIT_LATER : NNTP_CANTPOST);
         return;
       }
       
       if (LockPostRec(path) == 0) {
         syslog(L_ERROR, "%s Error write locking '%s'",
                ClientHost, path);
-        Reply("%s\r\n", NNTP_CANTPOST);
+        Reply("%s\r\n", ihave ? NNTP_RESENDIT_LATER : NNTP_CANTPOST);
         return;
       }
       
       if (!RateLimit(&sleeptime,path)) {
 	syslog(L_ERROR, "%s can't check rate limit info", ClientHost);
-	Reply("%s\r\n", NNTP_CANTPOST);
+	Reply("%s\r\n", ihave ? NNTP_RESENDIT_LATER : NNTP_CANTPOST);
         UnlockPostRec(path);
 	return;
       } else if (sleeptime != 0L) {
