@@ -1,4 +1,4 @@
-/*  $Id: group.c,v 1.62 2003/02/10 03:28:25 rra Exp $
+/*  $Id: group.c 7953 2008-08-23 13:45:02Z iulius $
 **
 **  Newsgroups and the active file.
 */
@@ -31,14 +31,17 @@ void CMDgroup(int ac, char *av[])
 #endif /* DO_PYTHON */
 
     if (!hookpresent && !PERMcanread) {
-	Reply("%s\r\n", NOACCESS);
+        if (PERMspecified)
+	    Reply("%d Permission denied\r\n", NNTP_ACCESS_VAL);
+        else
+            Reply("%d Authentication required\r\n", NNTP_AUTH_NEEDED_VAL);
 	return;
     }
 
     /* Parse arguments. */
     if (ac == 1) {
 	if (GRPcur == NULL) {
-	    Printf("%d No group specified\r\n", NNTP_XGTITLE_BAD);
+	    Printf("%d No group specified\r\n", NNTP_NOTINGROUP_VAL);
 	    return;
 	} else {
 	    group = xstrdup(GRPcur);
@@ -72,18 +75,17 @@ void CMDgroup(int ac, char *av[])
     }
 #endif /* DO_PYTHON */
 
-    /* If permission is denied, pretend group doesn't exist. */
     if (!hookpresent) {
         if (PERMspecified) {
             grplist[0] = group;
             grplist[1] = NULL;
             if (!PERMmatch(PERMreadlist, grplist)) {
-	         Reply("%s %s\r\n", NOSUCHGROUP, group);
-                 free(group);
-                 return;
+                Reply("%d Permission denied\r\n", NNTP_ACCESS_VAL);
+                free(group);
+                return;
             }
         } else {
-            Reply("%s %s\r\n", NOSUCHGROUP, group);
+            Reply("%d Authentication required\r\n", NNTP_AUTH_NEEDED_VAL);
             free(group);
             return;
         }
@@ -128,9 +130,8 @@ void CMDgroup(int ac, char *av[])
 		}
 		OVclosesearch(handle);
 	    }
-	    Reply("%d %d %ld %ld %s\r\n",
-		NNTP_GROUPOK_VAL,
-		count, ARTlow, ARThigh, group);
+	    Reply("%d %d %lu %lu %s\r\n", NNTP_GROUPOK_VAL, count,
+                  (unsigned long) ARTlow, (unsigned long) ARThigh, group);
 	}
 	GRPcount++;
 	ARTnumber = ARTlow;
@@ -147,16 +148,16 @@ void CMDgroup(int ac, char *av[])
            something bland here ("Article list follows"), but reference NNTP
            returns the same data as GROUP does and since we have it all
            available it shouldn't hurt to return the same thing. */
-	if ((handle = OVopensearch(group, ARTlow, ARThigh)) != NULL) {
-            if (count == 0)
-                Reply("%d 0 0 0 %s\r\n", NNTP_GROUPOK_VAL, group);
-            else
-                Reply("%d %d %ld %ld %s\r\n", NNTP_GROUPOK_VAL, count,
-                      ARTlow, ARThigh, group);
+        if (count == 0) {
+            Reply("%d 0 0 0 %s\r\n", NNTP_GROUPOK_VAL, group);
+            Printf(".\r\n");
+        } else if ((handle = OVopensearch(group, ARTlow, ARThigh)) != NULL) {
+            Reply("%d %d %lu %lu %s\r\n", NNTP_GROUPOK_VAL, count,
+                  (unsigned long) ARTlow, (unsigned long) ARThigh, group);
 	    while (OVsearch(handle, &i, NULL, NULL, &token, NULL)) {
 		if (PERMaccessconf->nnrpdcheckart && !ARTinstorebytoken(token))
 		    continue;
-		Printf("%ld\r\n", i);
+		Printf("%lu\r\n", (unsigned long) i);
 	    }
 	    OVclosesearch(handle);
 	    Printf(".\r\n");
@@ -189,7 +190,8 @@ GRPreport()
 
     if (GRPcur) {
 	strlcpy(buff, GRPcur, sizeof(buff));
-	syslog(L_NOTICE, "%s group %s %ld", ClientHost, buff, GRParticles);
+	syslog(L_NOTICE, "%s group %s %lu", ClientHost, buff,
+               (unsigned long) GRParticles);
 	GRParticles = 0;
 	repbuff[0]='\0';
     }
