@@ -1,4 +1,4 @@
-/*  $Id: nnrpd.c,v 1.171.2.2 2003/06/04 02:59:33 rra Exp $
+/*  $Id: nnrpd.c 8144 2008-10-25 17:06:15Z iulius $
 **
 **  NNTP server for readers (NNRP) for InterNetNews.
 **
@@ -79,7 +79,6 @@ char	*HISTORY = NULL;
 char	*NEWSGROUPS = NULL;
 char	*NNRPACCESS = NULL;
 
-bool	ForceReadOnly = false;
 static char 	*LocalLogFileName = NULL;
 static char 	*LocalLogDirName;
 
@@ -105,8 +104,6 @@ bool   PerlLoaded = false;
 bool PY_use_dynamic = false;
 #endif /* DO_PYTHON */
 
-bool LLOGenable;
-
 static char	CMDfetchhelp[] = "[MessageID|Number]";
 
 static CMDENT	CMDtable[] = {
@@ -133,12 +130,12 @@ static CMDENT	CMDtable[] = {
     {	"last",		CMDnextlast,	true,	1,	1,
 	NULL },
     {	"list",		CMDlist,	true,	1,	3,
-	"[active|active.times|extensions|newsgroups|distributions|distrib.pats|overview.fmt|subscriptions|motd]" },
+	"[active [wildmat]|active.times [wildmat]|distrib.pats|distributions|extensions|moderators|motd|newsgroups [wildmat]|overview.fmt|subscriptions]" },
     {	"listgroup",	CMDgroup,	true,	1,	2,
-	"newsgroup" },
+	"[newsgroup]" },
     {	"mode",		CMDmode,	false,	2,	2,
 	"reader" },
-    {	"newgroups",	CMDnewgroups,	true,	3,	5,
+    {	"newgroups",	CMDnewgroups,	true,	3,	4,
 	"[YY]yymmdd hhmmss [\"GMT\"]" },
     {	"newnews",	CMDnewnews,	true,	4,	5,
 	"newsgroups [YY]yymmdd hhmmss [\"GMT\"]" },
@@ -244,8 +241,10 @@ ExitWithStats(int x, bool readconf)
     if (History)
 	HISclose(History);
 
-    TMRsummary(ClientHost, timer_name);
-    TMRfree();
+    if (innconf->timer != 0) {
+        TMRsummary(ClientHost, timer_name);
+        TMRfree();
+    }
 
     if (LocalLogFileName != NULL)
 	free(LocalLogFileName);
@@ -386,6 +385,7 @@ Address2Name6(struct sockaddr *sa, char *hostname, int i)
     int ret;
     bool valid = 0;
     struct addrinfo hints, *res, *res0;
+    char *p;
 
     /* Get the official hostname, store it away. */
     ret = getnameinfo( sa, SA_LEN( sa ), hostname, i, NULL, 0, NI_NAMEREQD );
@@ -424,9 +424,13 @@ Address2Name6(struct sockaddr *sa, char *hostname, int i)
 
     freeaddrinfo( res0 );
 
-    if( valid ) return true;
-    else
-    {
+    if (valid) {
+        /* Make all lowercase for matching. */
+        for (p = hostname; *p != '\0'; p++)
+            if (CTYPE(isupper, *p))
+                *p = tolower(*p);
+        return true;
+    } else {
 	HostErrorStr = mismatch_error;
 	return false;
     }
@@ -800,9 +804,9 @@ main(int argc, char *argv[])
     struct		timeval tv;
     unsigned short	ListenPort = NNTP_PORT;
 #ifdef HAVE_INET6
-    char		ListenAddr[INET6_ADDRSTRLEN];
+    char		ListenAddr[INET6_ADDRSTRLEN] = "::0";
 #else
-    char		ListenAddr[16];
+    char		ListenAddr[16] = "0.0.0.0";
 #endif
     int			lfd, fd;
     socklen_t		clen;
@@ -862,9 +866,9 @@ main(int argc, char *argv[])
         exit(1);
 
 #ifdef HAVE_SSL
-    while ((i = getopt(argc, argv, "c:b:Dfi:I:g:nop:P:Rr:s:tS")) != EOF)
+    while ((i = getopt(argc, argv, "c:b:Dfi:I:g:nop:P:r:s:tS")) != EOF)
 #else
-    while ((i = getopt(argc, argv, "c:b:Dfi:I:g:nop:P:Rr:s:t")) != EOF)
+    while ((i = getopt(argc, argv, "c:b:Dfi:I:g:nop:P:r:s:t")) != EOF)
 #endif /* HAVE_SSL */
 	switch (i) {
 	default:
@@ -906,9 +910,6 @@ main(int argc, char *argv[])
  	case 'p':			/* tcp port for daemon mode */
  	    ListenPort = atoi(optarg);
  	    break;
-	case 'R':			/* Ignore 'P' option in access file */
-	    ForceReadOnly = true;
-	    break;
 	case 'r':			/* Reject connection message */
 	    Reject = xstrdup(optarg);
 	    break;
@@ -947,11 +948,14 @@ main(int argc, char *argv[])
     SPOOLlen = strlen(innconf->patharticles);
 
     if (DaemonMode) {
+        bool ipv4binding = true;
+
 #ifdef HAVE_INET6
 	memset(&ssa, '\0', sizeof(struct sockaddr_in6));
 	ssa6->sin6_family = AF_INET6;
 	ssa6->sin6_port   = htons(ListenPort);
 	if (inet_pton(AF_INET6, ListenAddr, ssa6->sin6_addr.s6_addr) > 0) {
+            ipv4binding = false;
 	    if ( (lfd = socket(AF_INET6, SOCK_STREAM, 0)) < 0) {
 		syslog(L_FATAL, "can't open socket (%m)");
 		exit(1);
@@ -978,7 +982,9 @@ main(int argc, char *argv[])
 	    exit(1);
 	}
 
-	if (bind(lfd, (struct sockaddr *) &ssa, sizeof(ssa)) < 0) {
+        if (bind(lfd, (struct sockaddr *) &ssa,
+                 ipv4binding ? sizeof(struct sockaddr_in)
+                             : sizeof(struct sockaddr_storage)) < 0) {
 	    fprintf(stderr, "%s: can't bind (%s)\n", argv[0], strerror(errno));
 	    syslog(L_FATAL, "can't bind local address (%m)");
 	    exit(1);
@@ -1128,7 +1134,8 @@ main(int argc, char *argv[])
 	close(fd);
 	dup2(0, 1);
 	dup2(0, 2);
-        TMRinit(TMR_MAX);
+        if (innconf->timer != 0)
+            TMRinit(TMR_MAX);
         STATstart = TMRnow_double();
 	SetupDaemon();
 
@@ -1142,7 +1149,8 @@ main(int argc, char *argv[])
 	xsignal(SIGCHLD, SIG_DFL);
  
     } else {
-        TMRinit(TMR_MAX);
+        if (innconf->timer)
+            TMRinit(TMR_MAX);
         STATstart = TMRnow_double();
 	SetupDaemon();
 	/* Arrange to toggle tracing. */
