@@ -1,4 +1,4 @@
-/*  $Id: buffindexed.c 6854 2004-05-20 22:23:28Z rra $
+/*  $Id: buffindexed.c 8207 2008-12-02 17:36:30Z iulius $
 **
 **  Overview buffer and index method.
 */
@@ -217,7 +217,7 @@ typedef enum {SRCH_FRWD, SRCH_BKWD} SRCH;
 
 static char LocalLogName[] = "buffindexed";
 static long		pagesize = 0;
-static OVBUFF		*ovbufftab;
+static OVBUFF		*ovbufftab = NULL;
 static int              GROUPfd;
 static GROUPHEADER      *GROUPheader = NULL;
 static GROUPENTRY       *GROUPentries = NULL;
@@ -312,8 +312,8 @@ static bool ovparse_part_line(char *l) {
   }
   l = ++p;
 
-  /* Length/size of symbolic partition */
-  len = strtoul(l, NULL, 10) * 1024;     /* This value in KB in decimal */
+  /* Length/size of symbolic partition in KB */
+  len = strtoul(l, NULL, 10) * (off_t) 1024;
   /*
   ** The minimum article offset will be the size of the bitfield itself,
   ** len / (blocksize * 8), plus however many additional blocks the OVBUFFHEAD
